pub enum FileMode {
Read,
Write,
Append,
Delete,
}Expand description
File access mode for GovernanceAction::FileAccess.
Variants
Read
Open the file for reading only.
Write
Open the file for writing, truncating any existing content.
Append
Open the file for writing, appending to existing content.
Delete
Delete the file from the filesystem.